@@ -1,5 +1,4 @@
 #!/usr/bin/env ruby
-
 require 'test/unit'
 require 'ruby-prof'
 require 'prime'
@@ -8,21 +7,24 @@ require 'test_helper'
 
 # --  Tests ----
 class PrintersTest < Test::Unit::TestCase
-  def test_printer
+  def test_printers
     result = RubyProf.profile do
-			run_primes
-		end
+      run_primes
+    end
     
-		printer = RubyProf::FlatPrinter.new(result)
+    printer = RubyProf::FlatPrinter.new(result)
+    printer.print(STDOUT)
+    
+    printer = RubyProf::GraphHtmlPrinter.new(result)
+    printer.print
+    
+    printer = RubyProf::GraphPrinter.new(result)
+    printer.print
+    
+    printer = RubyProf::CallTreePrinter.new(result)
     printer.print(STDOUT)
 
-		printer = RubyProf::GraphHtmlPrinter.new(result)
-    printer.print(STDOUT)
-        
-		printer = RubyProf::GraphPrinter.new(result)
-    printer.print(STDOUT)
-    
     # we should get here
     assert(true)
   end
-end
\ No newline at end of file
+end
